<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>所有文件 (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>飞行模式</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>停止无线通信</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>打开飞行模式将关闭无线网络、个人热点和蓝牙功能</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>应用代理</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>设置代理服务器</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理类型</translation>
    </message>
    <message>
        <source>http</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>socks4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>socks5</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>无效的IP地址</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>无效的端口</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>选填</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>配置好代理后，可在启动器的应用右键菜单查看“使用代理”选项，勾选后即可使用代理</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>设置拨号网络连接</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>添加PPPoE连接</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>网络属性</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>您确定要删除当前配置吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>网络详情</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>查看所有网络配置</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>信息已复制</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>网络检测</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2个人版</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3个人版</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 GHz</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>不指定设备</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>个人热点</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>共享网络</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>我的热点</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>编辑我的热点</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>名称（SSID）</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>频段</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>共享设置</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>共享热点的网卡设备</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>若要使用个人热点功能，请先退出飞行模式，再启用无线网卡。</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>若要使用个人热点功能，请先退出&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;飞行模式&lt;/a&gt;，再启用无线网卡。</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>网络属性</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>您确定要删除当前配置吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>系统代理</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>设置代理服务器</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理类型</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>配置URL</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP代理</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS代理</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP代理</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS代理</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>忽略以上主机和域的代理配置</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>连接、添加、导入</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>添加VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>导入VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import Error</source>
        <translation>导入错误</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>导入文件错误</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>网络属性</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN类型</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PPTP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPNC</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>您确定要删除当前配置吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导 出</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation>保 存</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>连接、编辑网络设置</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>请您先插入网线！</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>添加网络设置</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>连接、编辑网络设置</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>断开</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation>我的网络</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>其他网络</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>若要使用无线网络功能，请先关闭飞行模式</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>若要使用无线网络功能，请先关闭&lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;飞行模式&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>若要连接并使用无线网络功能，请先关闭热点分享</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>若要连接并使用无线网络功能，请先&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;关闭热点分享&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>无效的IP地址</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>不指定设备</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>以太网</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>设备MAC地址</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>克隆MAC地址</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>自定义MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Band</source>
        <translation>频段</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 GHz</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>通用</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>名称（SSID）</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>自动连接</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>禁用</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>方法</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>仅用于相对应的网络上的资源</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>无效的IP地址</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子网掩码</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>禁用</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手动</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>方法</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>仅用于相对应的网络上的资源</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP 地址</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>无效的IP地址</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前缀</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>使用MPPE点到点加密</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>使用128位MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>使用带状态的MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>拒绝EAP认证</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>拒绝PAP认证</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>拒绝CHAP认证</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>拒绝MSCHAP认证</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>拒绝MSCHAPv2认证</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>无BSD数据压缩</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>无Deflate数据压缩</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>无TCP头压缩</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>发送PPP回响包</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>拨号</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>服务</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MD5</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>FAST</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>隧道TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>受保护的EAP</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>GTC</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MSCHAPV2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PAP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MSCHAP</source>
        <translation>MSCHAP</translation>
    </message>
    <message>
        <source>CHAP</source>
        <translation>CHAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2个人版</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2企业版</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3个人版</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP认证</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>身份</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密码选项</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>仅为该用户存储密码</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>存储所有用户密码</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>总是询问</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>密钥</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私钥密码</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>安全认证类型</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>共享密钥</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>开放式系统</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私钥</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>匿名身份</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>自动PAC配置</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>匿名</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>已认证</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>兼有</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC文件</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA证书</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>用户证书</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP版本</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>自动</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>版本0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>版本1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>内部认证</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>所有文件 (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>无效的网关地址</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA证书</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>代理</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>允许思科安全桌面木马</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD 脚本</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>认证类型</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>私钥</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH代理</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>智能卡</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>预共享密钥</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>用户证书</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>为密钥口令句使用FSID</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>证书（TLS）</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>证书和密码（TLS）</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>静态密钥</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>密码选项</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>已保存的</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>总是询问</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>不要求</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私钥密码</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>自定义密钥方向</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>密钥方向</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>远程IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>本地IP</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT域</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>请求内部IP地址</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>强制使用UDP封装</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>使用IP压缩</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>启用自定义加密方案</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>组名</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>组密码</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>使用混合认证</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA文件</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>使用MPPE点到点加密</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>都可用（默认）</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40位（较安全）</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128位（最安全）</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>使用带状态的MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>拒绝EAP认证</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>拒绝PAP认证</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>拒绝CHAP认证</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>拒绝MSCHAP认证</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>拒绝MSCHAPv2认证</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>无BSD数据压缩</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>无Deflate数据压缩</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>无TCP头压缩</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>无协议字段压缩</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>无地址/控制压缩</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>发送PPP回响包</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>启用IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>组ID</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>密钥交换协议</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>安全封装协议</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN高级选项</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>自定义网关端口</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>网关端口</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>自定义重新协商间隔</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>重新协商间隔</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>使用LZO压缩</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>使用TCP连接</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>使用TAP设备</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>自定义最大传输单元(MTU)</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>自定义UDP数据报段长度</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP数据报段长度</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>限制隧道TCP最大段长度(MSS)</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>随机远程主机</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>域</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>供应商</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>思科（默认）</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>网屏</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>安全（默认）</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>弱</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT遍历</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T若可用（默认）</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>总是NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>思科UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH 组</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2（默认）</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>前向保密</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>服务器（默认）</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>本地端口</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>禁用死端检测</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>VPN安全</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>加密</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>DES-CBC</source>
        <translation>DES-CBC</translation>
    </message>
    <message>
        <source>RC2-CBC</source>
        <translation>RC2-CBC</translation>
    </message>
    <message>
        <source>DES-EDE-CBC</source>
        <translation>DES-EDE-CBC</translation>
    </message>
    <message>
        <source>DES-EDE3-CBC</source>
        <translation>DES-EDE3-CBC</translation>
    </message>
    <message>
        <source>DESX-CBC</source>
        <translation>DESX-CBC</translation>
    </message>
    <message>
        <source>BF-CBC</source>
        <translation>BF-CBC</translation>
    </message>
    <message>
        <source>RC2-40-CBC</source>
        <translation>RC2-40-CBC</translation>
    </message>
    <message>
        <source>CAST5-CBC</source>
        <translation>CAST5-CBC</translation>
    </message>
    <message>
        <source>RC2-64-CBC</source>
        <translation>RC2-64-CBC</translation>
    </message>
    <message>
        <source>AES-128-CBC</source>
        <translation>AES-128-CBC</translation>
    </message>
    <message>
        <source>AES-192-CBC</source>
        <translation>AES-192-CBC</translation>
    </message>
    <message>
        <source>AES-256-CBC</source>
        <translation>AES-256-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-128-CBC</source>
        <translation>CAMELLIA-128-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-192-CBC</source>
        <translation>CAMELLIA-192-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-256-CBC</source>
        <translation>CAMELLIA-256-CBC</translation>
    </message>
    <message>
        <source>SEED-CBC</source>
        <translation>SEED-CBC</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN代理</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>代理类型</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>服务器地址</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>失败时重试</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS 认证</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>主题匹配</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>远程证书类型</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>客户端</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>服务器</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>密钥文件</translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>选填</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>需要认证</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>若要使用无线网络功能，请先关闭 &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;飞行模式&lt;/a&gt; </translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP冲突</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>有线连接 %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE连接 %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>正在连接“%1”</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>“%1”已连接</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>“%1”已断开连接</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>无法连接“%1”，请检查您的路由器或网线。</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>无法连接“%1”，请靠近无线路由器</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>连接失败，无法连接“%1”，密码错误</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>连接“%1”需要密码</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>找不到无线网络“%1”</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>要连接“%1”，请在登录后设置您的身份验证信息</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>系统代理</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>VPN配置未连接或连接失败。请&lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;前往控制中心&lt;/a&gt;进行检查。</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>有线网络</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>连接到隐藏网络</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>我的网络</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>其他网络</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
</context>
</TS>